@@ -36,7 +36,6 @@
 |*     those rights set forth herein.                                        *|
 |*                                                                           *|
  \***************************************************************************/
-/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/nv/nv_hw.c,v 1.21 2006/06/16 00:19:33 mvojkovi Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -1501,6 +1500,7 @@ void NVLoadStateExt (
     } else {
        pNv->PRAMDAC[0x0848/4] = state->scale;
        pNv->PRAMDAC[0x0828/4] = state->crtcSync;
+       pNv->PRAMDAC[0x0808/4] = state->crtcVSync;
     }
     pNv->PRAMDAC[0x0600/4] = state->general;
 
@@ -1588,6 +1588,7 @@ void NVUnloadStateExt
 
     if(pNv->FlatPanel) {
        state->crtcSync = pNv->PRAMDAC[0x0828/4];
+       state->crtcVSync = pNv->PRAMDAC[0x0808/4];
     }
 }
 
@@ -1603,5 +1604,3 @@ void NVSetStartAddress (
         pNv->PCRTC[0x800/4] = start;
     }
 }
-
-
